from rq_controller.rq_workflow import WorkflowNode
import pytest
from rq_controller.common import PyProjection, PyProjectionGeometry, PyRegionOfIntrest, PyVolume
import rclpy
import numpy as np


rclpy.init()


@pytest.fixture
def workflow_node():
    return WorkflowNode()


def test_aquire_image(workflow_node: WorkflowNode):
    scan_pose = PyProjection.dummy()
    scan_pose.exposure_time_ms = 420.
    projection = workflow_node.aquire_projection(scan_pose)

    assert scan_pose.exposure_time_ms + 1. == projection.exposure_time_ms
    assert isinstance(projection, PyProjection)


def test_defect_detection(workflow_node: WorkflowNode):
    projection = PyProjection.dummy()

    roi = workflow_node.defect_detection([projection])
    
    assert isinstance(roi, list)
    assert isinstance(roi[0], PyRegionOfIntrest)


def test_trajectory(workflow_node: WorkflowNode):
    roi = [PyRegionOfIntrest.dummy()]
    workflow_node.trajectory_initialize(roi)

    scan_pose = PyProjection.dummy()
    next_scan_pose, finished = workflow_node.trajectory_update(scan_pose)

    assert isinstance(finished, bool)
    assert isinstance(next_scan_pose, PyProjection)


def test_reconstruction(workflow_node: WorkflowNode):
    roi = PyRegionOfIntrest.dummy()
    projections = [PyProjection.dummy()]

    volume = workflow_node.get_volume(projections, roi)

    assert volume.shape == roi.shape
    assert isinstance(volume, PyVolume)
